summaryrefslogtreecommitdiff
path: root/test/fs.py
diff options
context:
space:
mode:
Diffstat (limited to 'test/fs.py')
-rw-r--r--test/fs.py14
1 files changed, 7 insertions, 7 deletions
diff --git a/test/fs.py b/test/fs.py
index e9540169..2199a645 100644
--- a/test/fs.py
+++ b/test/fs.py
@@ -405,12 +405,12 @@ def run_file(binary):
assert closing == [b'error shell gone\n'], closing
-def kill_answers(binary):
- """Kill written to /ctl is answered before the editor quits."""
- with tempfile.TemporaryDirectory(prefix='pardes-kill-') as directory:
+def exit_answers(binary):
+ """Exit written to /ctl is answered before the editor quits."""
+ with tempfile.TemporaryDirectory(prefix='pardes-exit-') as directory:
seen = {}
- with session(binary, Path(directory), 'kill', terminal=seen) as (client, _):
- client.write('/ctl', b'Kill\n')
+ with session(binary, Path(directory), 'exit', terminal=seen) as (client, _):
+ client.write('/ctl', b'Exit\n')
deadline = time.monotonic() + 5
while time.monotonic() < deadline:
try:
@@ -421,13 +421,13 @@ def kill_answers(binary):
break
time.sleep(.01)
else:
- raise AssertionError('Kill did not quit the editor')
+ raise AssertionError("Exit did not quit the editor")
def test(binary, quic=False):
started = time.monotonic()
run_file(binary)
- kill_answers(binary)
+ exit_answers(binary)
for options, message in [
(['--fs'], b'no such option'),
(['--fs9'], b'no such option'),